==> derby-0.1.0.tgz: package/lib/parser.js <==
var addConditionalStyle, addDomEvent, distribute, modelPath, replaceIndex, splitBind;
replaceIndex = function(data, path, noReplace) {
  var i, indicies;
  if (noReplace || !(indicies = data.$i) || !path) {
    return path;
  }
  i = 0;
  return path.replace(/\$#/g, function() {
    return indicies[i++];
  });
};
addConditionalStyle = function(attrs, name, invert, styleText) {
  var cat, style, type;
  type = invert ? '#' : '^';
  cat = "{{" + type + name + "}}" + styleText + "{{/}}";
  return attrs.style = (style = attrs.style) ? "" + style + ";" + cat : cat;
};
splitBind = function(value) {
  var delay, name, out, pair, pairs, _i, _len, _ref, _ref2;
  pairs = value.replace(/\s/g, '').split(',');
  out = {};
  for (_i = 0, _len = pairs.length; _i < _len; _i++) {
    pair = pairs[_i];
    _ref = pair.split(':'), name = _ref[0], value = _ref[1];
    _ref2 = name.split('/'), name = _ref2[0], delay = _ref2[1];
    out[name] = {
      value: value,
      delay: delay
    };
  }
  return out;
};
module.exports = {
  modelPath: modelPath = function(data, name, noReplace) {
    var datum, i, path, paths;
    if ((paths = data.$paths) && name.charAt(0) === '.') {
      if (name === '.') {
        return replaceIndex(data, paths[0], noReplace);
      }
      i = /^\.+/.exec(name)[0].length - 1;
      return replaceIndex(data, paths[i], noReplace) + name.substr(i);
    }
    if (!((datum = data[name]) && (path = datum.model))) {
      return null;
    }
    return path.replace(/\[([^\]]+)\]/g, function(match, name) {
      return data[name];
    });
  },
  addDomEvent: addDomEvent = function(events, attrs, name, _eventNames, getMethod, property, invert) {
    var args, delay, eventName, eventNames, i, isArray, prefix, _len, _ref;
    args = [null, null, getMethod, property];
    if (isArray = Array.isArray(_eventNames)) {
      eventNames = [];
      for (i = 0, _len = _eventNames.length; i < _len; i++) {
        eventName = _eventNames[i];
        eventNames[i] = eventName.split('/');
      }
    } else {
      _ref = _eventNames.split('/'), eventName = _ref[0], delay = _ref[1];
      if (delay != null) {
        args.push(delay);
      }
    }
    prefix = invert ? '!' : '';
    return events.push(function(data, modelEvents, domEvents) {
      var _i, _len2, _ref2, _results;
      args[0] = prefix + modelPath(data, name);
      args[1] = attrs._id || attrs.id;
      if (!isArray) {
        return domEvents.bind(eventName, args);
      }
      _results = [];
      for (_i = 0, _len2 = eventNames.length; _i < _len2; _i++) {
        _ref2 = eventNames[_i], eventName = _ref2[0], delay = _ref2[1];
        _results.push(domEvents.bind(eventName, delay != null ? args.concat(delay) : args));
      }
      return _results;
    });
  },
  distribute: distribute = function(events, attrs, eventName) {
    var args;
    args = ['$dist', null];
    return events.push(function(data, modelEvents, domEvents) {
      args[1] = attrs._id || attrs.id;
      return domEvents.bind(eventName, args);
    });
  },
  parsePlaceholder: {
    'value': {
      input: function(events, attrs, name) {
        var eventNames;
        if ('x-blur' in attrs) {
          delete attrs['x-blur'];
          eventNames = 'change';
        } else {
          eventNames = 'input';
        }
        addDomEvent(events, attrs, name, eventNames, 'prop', 'value');
        return {
          method: 'propPolite'
        };
      }
    },
    'checked': {
      '*': function(events,  attrs, name, invert) {
        addDomEvent(events, attrs, name, 'change', 'prop', 'checked', invert);
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'selected': {
      '*': function(events, attrs, name, invert) {
        addDomEvent(events, attrs, name, 'change', 'prop', 'selected', invert);
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'disabled': {
      '*': function() {
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'x-visible': {
      '*': function(events, attrs, name, invert) {
        addConditionalStyle(attrs, name, invert, 'visibility:hidden');
        return {
          method: 'visible',
          del: true
        };
      }
    },
    'x-displayed': {
      '*': function(events, attrs, name, invert) {
        addConditionalStyle(attrs, name, invert, 'display:none');
        return {
          method: 'displayed',
          del: true
        };
      }
    }
  },
  parseElement: {
    'select': function(events, attrs) {
      distribute(events, attrs, 'change');
      return {
        addId: true
      };
    }
  },
  parseAttr: {
    'x-bind': {
      '*': function(events, attrs, value) {
        var name, obj, _fn, _ref;
        delete attrs['x-bind'];
        _ref = splitBind(value);
        _fn = function(name) {
          var args, delay;
          value = obj.value, delay = obj.delay;
          args = [value, null];
          if (delay != null) {
            args.push(delay);
          }
          return events.push(function(data, modelEvents, domEvents) {
            args[1] = attrs._id || attrs.id;
            return domEvents.bind(name, args);
          });
        };
        for (name in _ref) {
          obj = _ref[name];
          _fn(name);
        }
        return {
          addId: true
        };
      },
      a: function(events, attrs, value) {
        var obj;
        obj = splitBind(value);
        if ('click' in obj && !('href' in attrs)) {
          attrs.href = '#';
          if (!('onclick' in attrs)) {
            return attrs.onclick = 'return false';
          }
        }
      },
      form: function(events, attrs, value) {
        var obj;
        obj = splitBind(value);
        if ('submit' in obj) {
          if (!('onsubmit' in attrs)) {
            return attrs.onsubmit = 'return false';
          }
        }
      }
    }
  }
};

==> derby-0.1.2.tgz: package/lib/parser.js <==
var addConditionalStyle, addDomEvent, distribute, modelPath, replaceIndex, splitBind;
replaceIndex = function(data, path, noReplace) {
  var i, indicies;
  if (noReplace || !(indicies = data.$i) || !path) {
    return path;
  }
  i = 0;
  return path.replace(/\$#/g, function() {
    return indicies[i++];
  });
};
addConditionalStyle = function(attrs, name, invert, styleText) {
  var cat, style, type;
  type = invert ? '#' : '^';
  cat = "{{" + type + name + "}}" + styleText + "{{/}}";
  return attrs.style = (style = attrs.style) ? "" + style + ";" + cat : cat;
};
splitBind = function(value) {
  var delay, name, out, pair, pairs, _i, _len, _ref, _ref2;
  pairs = value.replace(/\s/g, '').split(',');
  out = {};
  for (_i = 0, _len = pairs.length; _i < _len; _i++) {
    pair = pairs[_i];
    _ref = pair.split(':'), name = _ref[0], value = _ref[1];
    _ref2 = name.split('/'), name = _ref2[0], delay = _ref2[1];
    out[name] = {
      value: value,
      delay: delay
    };
  }
  return out;
};
module.exports = {
  modelPath: modelPath = function(data, name, noReplace) {
    var i, paths;
    if (name in data) {
      return null;
    }
    if (name.charAt(0) === '.' && (paths = data.$paths)) {
      if (name === '.') {
        return replaceIndex(data, paths[0], noReplace);
      }
      i = /^\.+/.exec(name)[0].length - 1;
      return replaceIndex(data, paths[i], noReplace) + name.substr(i);
    }
    return name.replace(/\[([^\]]+)\]/g, function(match, name) {
      return data[name];
    });
  },
  addDomEvent: addDomEvent = function(events, attrs, name, _eventNames, getMethod, property, invert) {
    var args, delay, eventName, eventNames, i, isArray, prefix, _len, _ref;
    args = [null, null, getMethod, property];
    if (isArray = Array.isArray(_eventNames)) {
      eventNames = [];
      for (i = 0, _len = _eventNames.length; i < _len; i++) {
        eventName = _eventNames[i];
        eventNames[i] = eventName.split('/');
      }
    } else {
      _ref = _eventNames.split('/'), eventName = _ref[0], delay = _ref[1];
      if (delay != null) {
        args.push(delay);
      }
    }
    prefix = invert ? '!' : '';
    return events.push(function(data, modelEvents, domEvents) {
      var _i, _len2, _ref2, _results;
      args[0] = prefix + modelPath(data, name);
      args[1] = attrs._id || attrs.id;
      if (!isArray) {
        return domEvents.bind(eventName, args);
      }
      _results = [];
      for (_i = 0, _len2 = eventNames.length; _i < _len2; _i++) {
        _ref2 = eventNames[_i], eventName = _ref2[0], delay = _ref2[1];
        _results.push(domEvents.bind(eventName, delay != null ? args.concat(delay) : args));
      }
      return _results;
    });
  },
  distribute: distribute = function(events, attrs, eventName) {
    var args;
    args = ['$dist', null];
    return events.push(function(data, modelEvents, domEvents) {
      args[1] = attrs._id || attrs.id;
      return domEvents.bind(eventName, args);
    });
  },
  parsePlaceholder: {
    'value': {
      input: function(events, attrs, name) {
        var eventNames;
        if ('x-blur' in attrs) {
          delete attrs['x-blur'];
          eventNames = 'change';
        } else {
          eventNames = 'input';
        }
        addDomEvent(events, attrs, name, eventNames, 'prop', 'value');
        return {
          method: 'propPolite'
        };
      }
    },
    'checked': {
      '*': function(events,  attrs, name, invert) {
        addDomEvent(events, attrs, name, 'change', 'prop', 'checked', invert);
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'selected': {
      '*': function(events, attrs, name, invert) {
        addDomEvent(events, attrs, name, 'change', 'prop', 'selected', invert);
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'disabled': {
      '*': function() {
        return {
          method: 'prop',
          bool: true
        };
      }
    },
    'x-visible': {
      '*': function(events, attrs, name, invert) {
        addConditionalStyle(attrs, name, invert, 'visibility:hidden');
        return {
          method: 'visible',
          del: true
        };
      }
    },
    'x-displayed': {
      '*': function(events, attrs, name, invert) {
        addConditionalStyle(attrs, name, invert, 'display:none');
        return {
          method: 'displayed',
          del: true
        };
      }
    }
  },
  parseElement: {
    'select': function(events, attrs) {
      distribute(events, attrs, 'change');
      return {
        addId: true
      };
    }
  },
  parseAttr: {
    'x-bind': {
      '*': function(events, attrs, value) {
        var name, obj, _fn, _ref;
        delete attrs['x-bind'];
        _ref = splitBind(value);
        _fn = function(name) {
          var args, delay;
          value = obj.value, delay = obj.delay;
          args = [value, null];
          if (delay != null) {
            args.push(delay);
          }
          return events.push(function(data, modelEvents, domEvents) {
            args[1] = attrs._id || attrs.id;
            return domEvents.bind(name, args);
          });
        };
        for (name in _ref) {
          obj = _ref[name];
          _fn(name);
        }
        return {
          addId: true
        };
      },
      a: function(events, attrs, value) {
        var obj;
        obj = splitBind(value);
        if ('click' in obj && !('href' in attrs)) {
          attrs.href = '#';
          if (!('onclick' in attrs)) {
            return attrs.onclick = 'return false';
          }
        }
      },
      form: function(events, attrs, value) {
        var obj;
        obj = splitBind(value);
        if ('submit' in obj) {
          if (!('onsubmit' in attrs)) {
            return attrs.onsubmit = 'return false';
          }
        }
      }
    }
  }
};
